@@ -449,6 +449,9 @@ LockStruct  LockProcs[] =
 	{"sproingies",
 	 80000, 5, 0, 0, 64, 1.0, "",
 	 "Shows Sproingies!  Nontoxic.  Safe for pets and small children", 0, NULL, "#ifdef USE_GL"},
+	{"squiral",
+	 10000, 0, 50000, -3, 64, 1.0, "",
+	 "Shows spiral-producing automata", 0, NULL, NULL},
 	{"stairs",
 	 200000, 0, 1, 1, 64, 1.0, "",
 "Shows some Infinite Stairs, an Escher-like scene", 0, NULL, "#ifdef USE_GL"},
