@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 4 -*- */
 /* demon --- David Griffeath's cellular automata */
 
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)demon.c	5.24 2007/01/18 xlockmore";
 
 #endif
@@ -51,21 +51,20 @@ static const char sccsid[] = "@(#)demon.c	5.24 2007/01/18 xlockmore";
 
 #ifdef STANDALONE
 #define MODE_demon
-#define PROGCLASS "Demon"
-#define HACK_INIT init_demon
-#define HACK_DRAW draw_demon
-#define demon_opts xlockmore_opts
 #define DEFAULTS "*delay: 50000 \n" \
- "*count: 0 \n" \
- "*cycles: 1000 \n" \
- "*size: -7 \n" \
- "*ncolors: 64 \n" \
- "*neighbors: 0 \n"
+	"*count: 0 \n" \
+	"*cycles: 1000 \n" \
+	"*size: -7 \n" \
+	"*ncolors: 64 \n" \
+
+# define free_demon 0
+# define reshape_demon 0
+# define demon_handle_event 0
 #define UNIFORM_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
-
+#define DO_STIPPLE
 #endif /* STANDALONE */
 #include "automata.h"
 
@@ -104,7 +103,7 @@ static OptionStruct desc[] =
 	{(char *) "-/+colorsonly", (char *) "no black cells"}
 };
 
-ModeSpecOpt demon_opts =
+ENTRYPOINT ModeSpecOpt demon_opts =
 {sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
 
 #ifdef USE_MODULES
@@ -119,7 +118,7 @@ ModStruct   demon_description =
 #define DEMONBITS(n,w,h)\
   if ((dp->pixmaps[dp->init_bits]=\
   XCreatePixmapFromBitmapData(display,window,(char *)n,w,h,1,0,1))==None){\
-  free_demon(display,dp); return;} else {dp->init_bits++;}
+  free_demon_screen(display,dp); return;} else {dp->init_bits++;}
 
 #define REDRAWSTEP 2000		/* How many cells to draw per cycle */
 #define MINSTATES 2
@@ -378,10 +377,13 @@ free_struct(demonstruct * dp)
 }
 
 static void
-free_demon(Display *display, demonstruct *dp)
+free_demon_screen(Display *display, demonstruct *dp)
 {
 	int         shade;
 
+	if (dp == NULL) {
+		return;
+	}
 	if (dp->stippledGC != None) {
 		XFreeGC(display, dp->stippledGC);
 		dp->stippledGC = None;
@@ -391,6 +393,7 @@ free_demon(Display *display, demonstruct *dp)
 	}
 	dp->init_bits = 0;
 	free_struct(dp);
+	dp = NULL;
 }
 
 static Bool
@@ -474,8 +477,8 @@ draw_state(ModeInfo * mi, int state)
 		/* Free up rects list and the appropriate part of the cellList */
 		free(rects);
 	} else if (dp->neighbors == 5 || dp->neighbors == 7) {
-		current = dp->cellList[state];
 		int map[4] = {2, 0, 1, 3};
+		current = dp->cellList[state];
 		while (current) {
 			int col = current->pt.x;
 			int row = current->pt.y;
@@ -947,7 +950,7 @@ positionOfNeighbor(demonstruct * dp, int n, int col, int row)
 	return (row * dp->ncols + col);
 }
 
-void
+ENTRYPOINT void
 init_demon(ModeInfo * mi)
 {
 	Display    *display = MI_DISPLAY(mi);
@@ -955,11 +958,7 @@ init_demon(ModeInfo * mi)
 	int         size = MI_SIZE(mi), nk;
 	demonstruct *dp;
 
-	if (demons == NULL) {
-		if ((demons = (demonstruct *) calloc(MI_NUM_SCREENS(mi),
-					      sizeof (demonstruct))) == NULL)
-			return;
-	}
+	MI_INIT(mi, demons);
 	dp = &demons[MI_SCREEN(mi)];
 
 	dp->generation = 0;
@@ -971,7 +970,7 @@ init_demon(ModeInfo * mi)
 			gcv.fill_style = FillOpaqueStippled;
 			if ((dp->stippledGC = XCreateGC(display, window,
 				 GCFillStyle, &gcv)) == None) {
-				free_demon(display, dp);
+				free_demon_screen(display, dp);
 				return;
 			}
 		}
@@ -1004,11 +1003,11 @@ init_demon(ModeInfo * mi)
 		dp->states = plots[1][nk];
 	if ((dp->cellList = (CellList **) calloc(dp->states,
 		sizeof (CellList *))) == NULL) {
-		free_demon(display, dp);
+		free_demon_screen(display, dp);
 		return;
 	}
 	if ((dp->ncells = (int *) calloc(dp->states, sizeof (int))) == NULL) {
-		free_demon(display, dp);
+		free_demon_screen(display, dp);
 		return;
 	}
 
@@ -1169,20 +1168,20 @@ init_demon(ModeInfo * mi)
 
 	if ((dp->oldcell = (unsigned char *)
 		malloc(dp->ncols * dp->nrows * sizeof (unsigned char))) == NULL) {
-		free_demon(display, dp);
+		free_demon_screen(display, dp);
 		return;
 	}
 
 	if ((dp->newcell = (unsigned char *)
 		malloc(dp->ncols * dp->nrows * sizeof (unsigned char))) == NULL) {
-		free_demon(display, dp);
+		free_demon_screen(display, dp);
 		return;
 	}
 
 	RandomSoup(mi);
 }
 
-void
+ENTRYPOINT void
 draw_demon(ModeInfo * mi)
 {
 	int         i, j, k, l, n, mj = 0;
@@ -1218,7 +1217,7 @@ draw_demon(ModeInfo * mi)
 				if (dp->oldcell[i + mj] != dp->newcell[i + mj]) {
 					dp->oldcell[i + mj] = dp->newcell[i + mj];
 					if (!addtolist(mi, i, j, dp->oldcell[i + mj])) {
-						free_demon(MI_DISPLAY(mi), dp);
+						free_demon_screen(MI_DISPLAY(mi), dp);
 						return;
 					}
 					change = True;
@@ -1231,7 +1230,7 @@ draw_demon(ModeInfo * mi)
 	} else {
 		if (dp->ncells[dp->state])
 			if (!draw_state(mi, dp->state)) {
-				free_demon(MI_DISPLAY(mi), dp);
+				free_demon_screen(MI_DISPLAY(mi), dp);
 				return;
 			}
 		dp->state++;
@@ -1250,20 +1249,21 @@ draw_demon(ModeInfo * mi)
 	}
 }
 
-void
+ENTRYPOINT void
 release_demon(ModeInfo * mi)
 {
 	if (demons != NULL) {
 		int         screen;
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
-			free_demon(MI_DISPLAY(mi), &demons[screen]);
+			free_demon_screen(MI_DISPLAY(mi), &demons[screen]);
 		free(demons);
 		demons = (demonstruct *) NULL;
 	}
 }
 
-void
+#ifndef STANDALONE
+ENTRYPOINT void
 refresh_demon(ModeInfo * mi)
 {
 	demonstruct *dp;
@@ -1275,5 +1275,8 @@ refresh_demon(ModeInfo * mi)
 	dp->redrawing = 1;
 	dp->redrawpos = 0;
 }
+#endif
+
+XSCREENSAVER_MODULE ("Demon", demon)
 
 #endif /* MODE_demon */
