@@ -1,9 +1,8 @@
 /* -*- Mode: C; tab-width: 4 -*- */
 /* pipes --- 3D selfbuiding pipe system */
 
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)pipes.c	5.00 2000/11/01 xlockmore";
-
 #endif
 
 /*-
@@ -24,7 +23,7 @@ static const char sccsid[] = "@(#)pipes.c	5.00 2000/11/01 xlockmore";
  *
  * ==========================================================================
  * The routine myElbow is derivated from the doughnut routine from the MesaGL
- * library (more especifically the Mesaaux library) written by Brian Paul.
+ * library (more especially the Mesaaux library) written by Brian Paul.
  * ==========================================================================
  *
  * Thanks goes to Brian Paul for making it possible and inexpensive to use
@@ -34,7 +33,7 @@ static const char sccsid[] = "@(#)pipes.c	5.00 2000/11/01 xlockmore";
  * mistakes.
  *
  * My e-mail addresses is
- * mfvianna@centroin.com.br
+ * mfvianna AT centroin.com.br
  *
  * Marcelo F. Vianna (Apr-09-1997)
  *
@@ -45,31 +44,26 @@ static const char sccsid[] = "@(#)pipes.c	5.00 2000/11/01 xlockmore";
  */
 
 #ifdef VMS
-/*-
- * due to a Bug/feature in VMS X11/Intrinsic.h has to be placed before xlock.
- * otherwise caddr_t is not defined correctly
- */
-#include <X11/Intrinsic.h>
+#include <types.h>
 #endif
 
 #ifdef STANDALONE
-#define MODE_pipes
-#define PROGCLASS "Pipes"
-#define HACK_INIT init_pipes
-#define HACK_DRAW draw_pipes
-#define pipes_opts xlockmore_opts
-#define DEFAULTS "*delay: 1000 \n" \
- "*count: 2 \n" \
- "*cycles: 5 \n" \
- "*size: 500 \n" \
- "*fisheye: True \n" \
- "*tightturns: False \n" \
- "*rotatepipes: True \n" \
- "*noBuffer: True \n"
-#include "xlockmore.h"		/* from the xscreensaver distribution */
+# define MODE_pipes
+# define DEFAULTS	"*delay: 1000 \n" \
+			"*count: 2 \n" \
+			"*cycles: 5 \n" \
+			"*size: 500 \n" \
+			"*showFPS: False \n" \
+			"*fpsSolid: True \n" \
+			"*wireframe: True \n" \
+
+#define free_pipes 0
+#define reshape_pipes 0
+#define pipes_handle_event 0
+# include "xlockmore.h"		/* from the xscreensaver distribution */
 #else /* !STANDALONE */
-#include "xlock.h"		/* from the xlockmore distribution */
-#include "visgl.h"
+# include "xlock.h"		/* from the xlockmore distribution */
+# include "visgl.h"
 #endif /* !STANDALONE */
 
 #ifdef MODE_pipes
@@ -93,8 +87,8 @@ static XrmOptionDescRec opts[] =
 	{(char *) "+fisheye", (char *) ".pipes.fisheye", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-tightturns", (char *) ".pipes.tightturns", XrmoptionNoArg, (caddr_t) "on"},
 	{(char *) "+tightturns", (char *) ".pipes.tightturns", XrmoptionNoArg, (caddr_t) "off"},
-      {(char *) "-rotatepipes", (char *) ".pipes.rotatepipes", XrmoptionNoArg, (caddr_t) "on"},
-      {(char *) "+rotatepipes", (char *) ".pipes.rotatepipes", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "-rotatepipes", (char *) ".pipes.rotatepipes", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+rotatepipes", (char *) ".pipes.rotatepipes", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
 {
@@ -111,7 +105,7 @@ static OptionStruct desc[] =
 	{(char *) "-/+rotatepipes", (char *) "turn on/off pipe system rotation per screenful"}
 };
 
-ModeSpecOpt pipes_opts =
+ENTRYPOINT ModeSpecOpt pipes_opts =
 {sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
 
 #ifdef USE_MODULES
@@ -123,7 +117,7 @@ ModStruct   pipes_description =
  "change_pipes",
 #endif
  "change_pipes", (char *) NULL, &pipes_opts,
- 1000, 2, 5, 500, 4, 1.0, "",
+ 1000, 2, 5, 500, 64, 1.0, "",
  "Shows a selfbuilding pipe system", 0, NULL};
 
 #endif
@@ -445,11 +439,11 @@ MakeGuage(ModeInfo * mi, int newdir)
 {
 	pipesstruct *pp = &pipes[MI_SCREEN(mi)];
 
-	/* Can't have a guage on a vertical pipe. */
+	/* Can't have a gauge on a vertical pipe. */
 	if ((newdir == dirUP) || (newdir == dirDOWN))
 		return (0);
 
-	/* Is there space above this pipe for a guage? */
+	/* Is there space above this pipe for a gauge? */
 	if (!pp->directions[dirUP])
 		return (0);
 
@@ -634,6 +628,9 @@ pinit(ModeInfo * mi, int zera)
 static void
 free_factory(Display *display, pipesstruct *pp)
 {
+	if (pp == NULL) {
+		return;
+	}
 	if (pp->glx_context) {
 		/* Display lists MUST be freed while their glXContext is current. */
 #ifdef WIN32
@@ -678,9 +675,10 @@ free_factory(Display *display, pipesstruct *pp)
 			pp->guageconnector = 0;
 		}
 	}
+	pp = NULL;
 }
 
-void
+ENTRYPOINT void
 release_pipes(ModeInfo * mi)
 {
 	if (pipes != NULL) {
@@ -694,16 +692,12 @@ release_pipes(ModeInfo * mi)
 	FreeAllGL(mi);
 }
 
-void
+ENTRYPOINT void
 init_pipes(ModeInfo * mi)
 {
 	pipesstruct *pp;
 
-	if (pipes == NULL) {
-		if ((pipes = (pipesstruct *) calloc(MI_NUM_SCREENS(mi),
-					      sizeof (pipesstruct))) == NULL)
-			return;
-	}
+	MI_INIT(mi, pipes);
 	pp = &pipes[MI_SCREEN(mi)];
 
 	pp->window = MI_WINDOW(mi);
@@ -763,7 +757,7 @@ init_pipes(ModeInfo * mi)
 	}
 }
 
-void
+ENTRYPOINT void
 draw_pipes(ModeInfo * mi)
 {
 #if !defined(WIN32) || (defined( MESA ) && defined( SLOW ))
@@ -808,7 +802,7 @@ draw_pipes(ModeInfo * mi)
 
 	glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, pp->system_color);
 
-	/* If it's the begining of a system, draw a sphere */
+	/* If it's the beginning of a system, draw a sphere */
 	if (pp->olddir == dirNone) {
 		glPushMatrix();
 		glTranslatef((pp->PX - 16) / 3.0 * 4.0, (pp->PY - 12) / 3.0 * 4.0, (pp->PZ - 16) / 3.0 * 4.0);
@@ -835,7 +829,9 @@ draw_pipes(ModeInfo * mi)
 		/* If the maximum number of system was drawn, restart (clearing the screen), */
 		/* else start a new system. */
 		if (++pp->system_number > pp->number_of_systems) {
+#ifndef STANDALONE
 			(void) sleep(1);
+#endif
 			pinit(mi, 1);
 		} else {
 			pinit(mi, 0);
@@ -1075,7 +1071,8 @@ draw_pipes(ModeInfo * mi)
 #endif
 }
 
-void
+#ifndef STANDALONE
+ENTRYPOINT void
 change_pipes(ModeInfo * mi)
 {
 	pipesstruct *pp;
@@ -1093,5 +1090,8 @@ change_pipes(ModeInfo * mi)
 #endif
 	pinit(mi, 1);
 }
-
 #endif
+
+XSCREENSAVER_MODULE ("Pipes", pipes)
+
+#endif /* MODE_pipes */
