@@ -1,13 +1,13 @@
 /* -*- Mode: C; tab-width: 4 -*- */
 /* juggle */
 
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)juggle.c	5.10 2003/09/02 xlockmore";
 
 #endif
 
 /*-
- * Copyright (c) 1996 by Tim Auckland <tda10.geo@yahoo.com>
+ * Copyright (c) 1996 by Tim Auckland <tda10.geo AT yahoo.com>
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation for any purpose and without fee is hereby granted,
@@ -33,7 +33,7 @@ static const char sccsid[] = "@(#)juggle.c	5.10 2003/09/02 xlockmore";
  *              implementation, so that different objects can have
  *              different length trails.
  * 11-Nov-2004: [TDA] Clap when all the balls are in the air.
- * 10-Nov-2004: [TDA] Display pattern name converted to hight
+ * 10-Nov-2004: [TDA] Display pattern name converted to height
  *              notation.
  * 31-Oct-2004: [TDA] Add -clubs and new trail implementation.
  * 02-Sep-2003: Non-real time to see what is happening without a
@@ -131,17 +131,14 @@ static const char sccsid[] = "@(#)juggle.c	5.10 2003/09/02 xlockmore";
 
 #ifdef STANDALONE
 #define MODE_juggle
-#define PROGCLASS "Juggle"
-#define HACK_INIT init_juggle
-#define HACK_DRAW draw_juggle
-#define HACK_RESHAPE reshape_juggle
-#define _no_HACK_FREE release_juggle
-#define juggle_opts xlockmore_opts
 #define DEFAULTS "*delay: 10000 \n" \
-"*count: 200 \n" \
-"*cycles: 1000 \n" \
-"*ncolors: 32 \n" \
-"*font: -*-times-bold-r-normal-*-180-*\n"
+	"*count: 200 \n" \
+	"*cycles: 1000 \n" \
+	"*ncolors: 32 \n" \
+	"*font: -*-times-bold-r-normal-*-180-*\n" \
+
+# define free_juggle 0
+# define juggle_handle_event 0
 #undef SMOOTH_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #define MI_DELAY(MI)	((MI)->pause)
@@ -259,7 +256,7 @@ static OptionStruct desc[] =
   { "-only",           "Turn off all objects but the named one." },
 };
 
-ModeSpecOpt juggle_opts =
+ENTRYPOINT ModeSpecOpt juggle_opts =
   { XtNumber(opts), opts, XtNumber(vars), vars, desc };
 
 #ifdef USE_MODULES
@@ -677,7 +674,10 @@ trajectory_destroy(Trajectory *t) {
 }
 
 static void
-free_juggle(jugglestruct *sp) {
+free_juggle_screen(jugglestruct *sp) {
+  if (sp == NULL) {
+	return;
+  }
   if (sp->head != NULL) {
 	while (sp->head->next != sp->head) {
 	  trajectory_destroy(sp->head->next);
@@ -704,6 +704,7 @@ free_juggle(jugglestruct *sp) {
 	free(sp->pattern);
 	sp->pattern = NULL;
   }
+  sp = NULL;;
 }
 
 static Bool
@@ -713,7 +714,7 @@ add_throw(jugglestruct *sp, char type, int h, Notation n, const char* name)
 
   ADD_ELEMENT(Trajectory, t, sp->head->prev);
   if(t == NULL){ /* Out of Memory */
-	free_juggle(sp);
+	free_juggle_screen(sp);
 	return False;
   }
   t->object = NULL;
@@ -954,7 +955,7 @@ part(jugglestruct *sp)
 	  t->action = CATCH;
 	  ADD_ELEMENT(Trajectory, nt, p);
 	  if(nt == NULL){
-		free_juggle(sp);
+		free_juggle_screen(sp);
 		return False;
 	  }
 	  nt->object = NULL;
@@ -984,7 +985,7 @@ choose_object(void) {
   return o;
 }
 
-/* Connnect up throws and catches to figure out which ball goes where.
+/* Connect up throws and catches to figure out which ball goes where.
    Do the same with the juggler's hands. */
 
 static void
@@ -1560,7 +1561,7 @@ hands(jugglestruct *sp)
 	  continue;
 	}
 
-	/* double spline takes hand from throw, thru catch, to
+	/* double spline takes hand from throw, through catch, to
 	   next throw */
 
 	t->finish = u->start;
@@ -2316,14 +2317,14 @@ show_bball(ModeInfo *mi, unsigned long color, Trace *s)
  **************************************************************************/
 
 
-void
+ENTRYPOINT void
 release_juggle(ModeInfo * mi)
 {
   if (juggles != NULL) {
 	int screen;
 
 	for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
-	  free_juggle(&juggles[screen]);
+	  free_juggle_screen(&juggles[screen]);
 	free(juggles);
 	juggles = (jugglestruct *) NULL;
   }
@@ -2458,7 +2459,7 @@ refill_juggle(ModeInfo * mi)
   positions(sp);
 
   if (!projectile(sp)) {
-	free_juggle(sp);
+	free_juggle_screen(sp);
 	return;
   }
 
@@ -2467,7 +2468,8 @@ refill_juggle(ModeInfo * mi)
   if(MI_IS_DEBUG(mi)) dump(sp);
 #endif
 }
-void
+
+ENTRYPOINT void
 change_juggle(ModeInfo * mi)
 {
   jugglestruct *sp = NULL;
@@ -2499,19 +2501,11 @@ change_juggle(ModeInfo * mi)
 
 }
 
-#ifdef STANDALONE
-/* Used by xscreensaver.  xlock just uses init_juggle */
-void
-reshape_juggle(ModeInfo * mi, int width, int height)
-{
-  init_juggle(mi);
-}
-#endif
-
-void
+ENTRYPOINT void
 init_juggle(ModeInfo * mi)
 {
   jugglestruct *sp;
+  int screen;
   int i;
 
   if (only && *only && strcmp(only, " ")) {
@@ -2569,17 +2563,14 @@ init_juggle(ModeInfo * mi)
   XClearWindow(MI_DISPLAY(mi), MI_WINDOW(mi));
 
   if (juggles == NULL) { /* First-time initialisation */
-
-	/* allocate jugglestruct */
-	if ((juggles =
-		 (jugglestruct *)calloc(MI_NUM_SCREENS(mi),
-								sizeof (jugglestruct))) == NULL) {
-	  release_juggle(mi);
-	  return;
+	MI_INIT(mi, juggles);
+	for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++) {
+	  	sp = &juggles[screen];
+		sp->Gr = 0;
 	}
-
-	sp = &juggles[MI_SCREEN(mi)];
-
+  }
+  sp = &juggles[MI_SCREEN(mi)];
+  if (sp->Gr == 0) {
 	sp->count = ABS(MI_COUNT(mi));
 	if (sp->count == 0)
 	  sp->count = 200;
@@ -2606,21 +2597,21 @@ init_juggle(ModeInfo * mi)
 	/* create circular trajectory list */
 	ADD_ELEMENT(Trajectory, sp->head, sp->head);
 	if(sp->head == NULL){
-	  free_juggle(sp);
+	  free_juggle_screen(sp);
 	  return;
 	}
 
 	/* create circular object list */
 	ADD_ELEMENT(Object, sp->objects, sp->objects);
 	if(sp->objects == NULL){
-	  free_juggle(sp);
+	  free_juggle_screen(sp);
 	  return;
 	}
 
 	/* create circular wander list */
 	ADD_ELEMENT(Wander, sp->wander, sp->wander);
 	if(sp->wander == NULL){
-	  free_juggle(sp);
+	  free_juggle_screen(sp);
 	  return;
 	}
 	(void)wander(sp, 0); /* Initialize wander */
@@ -2630,14 +2621,11 @@ init_juggle(ModeInfo * mi)
 
 	/* Set up programme */
 	change_juggle(mi);
-
   }
 
   /* Only put things here that won't interrupt the programme during
 	 a window resize */
 
-  sp = &juggles[MI_SCREEN(mi)];
-
   /* Use MIN so that users can resize in interesting ways, eg
 	 narrow windows for tall patterns, etc */
   sp->scale = MIN(MI_HEIGHT(mi)/480.0, MI_WIDTH(mi)/160.0);
@@ -2647,7 +2635,7 @@ init_juggle(ModeInfo * mi)
   }
 }
 
-void
+ENTRYPOINT void
 draw_juggle(ModeInfo * mi)
 {
   Trajectory *traj = NULL;
@@ -2679,7 +2667,7 @@ draw_juggle(ModeInfo * mi)
   for (traj = sp->head->next; traj != sp->head; traj = traj->next) {
 	if (traj->status != PREDICTOR) {
 	  /* Skip any elements that need further processing */
-	  /* We could remove them, but there shoudn't be many and they
+	  /* We could remove them, but there shouldn't be many and they
 		 would be needed if we ever got the pattern refiller
 		 working */
 	  continue;
@@ -2844,4 +2832,15 @@ draw_juggle(ModeInfo * mi)
   }
 }
 
+#ifdef STANDALONE
+/* Used by xscreensaver.  xlock just uses init_juggle */
+ENTRYPOINT void
+reshape_juggle(ModeInfo * mi, int width, int height)
+{
+  init_juggle(mi);
+}
+#endif
+
+XSCREENSAVER_MODULE ("Juggle", juggle)
+
 #endif /* MODE_juggle */
