@@ -731,6 +731,12 @@ LockStruct  LockProcs[] =
 	 80000, 5, 0, 0, 64, 1.0, (char *) "",
   (char *) "Shows Sproingies!  Nontoxic.  Safe for pets and small children", 0, NULL},
 #endif
+#ifdef MODE_squiral
+	{(char *) "squiral", init_squiral, draw_squiral, release_squiral,
+	 init_squiral, init_squiral, (ModeHook *) NULL, &squiral_opts,
+	 10000, 0, 50000, -3, 64, 1.0, (char *) "",
+	 (char *) "Shows spiral-producing automata", 0, NULL},
+#endif
 #ifdef MODE_stairs
 	{(char *) "stairs", init_stairs, draw_stairs, release_stairs,
 	 draw_stairs, change_stairs, (ModeHook *) NULL, &stairs_opts,
