@@ -473,6 +473,7 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_munch
 #define MODE_nose
 #define MODE_pacman
+#define MODE_paterson
 #define MODE_penrose
 #define MODE_petal
 #define MODE_petri
@@ -493,7 +494,9 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_space /* should be combined with star some day */
 #define MODE_sphere
 #define MODE_spiral
+#define MODE_spirolateral
 #define MODE_spline
+#define MODE_squiral
 #define MODE_star
 #define MODE_starfish
 #define MODE_strange
@@ -563,6 +566,7 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_munch
 #define MODE_nose
 #define MODE_pacman
+#define MODE_paterson
 #define MODE_penrose
 #define MODE_petal
 #define MODE_puzzle
@@ -574,7 +578,9 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_space /* should be combined with star some day */
 #define MODE_sphere
 #define MODE_spiral
+#define MODE_spirolateral
 #define MODE_spline
+#define MODE_squiral
 #define MODE_star
 #define MODE_swarm
 #define MODE_tetris
@@ -675,14 +681,6 @@ extern ModeHook change_bevel;
 extern ModeSpecOpt bevel_opts;
 #endif
 
-#ifdef MODE_billiards
-extern ModeHook init_billiards;
-extern ModeHook draw_billiards;
-extern ModeHook release_billiards;
-extern ModeHook refresh_billiards;
-extern ModeSpecOpt billiards_opts;
-#endif
-
 #ifdef MODE_blot
 extern ModeHook init_blot;
 extern ModeHook draw_blot;
@@ -1300,6 +1298,13 @@ extern ModeHook change_pacman;
 extern ModeSpecOpt pacman_opts;
 #endif
 
+#ifdef MODE_paterson
+extern ModeHook init_paterson;
+extern ModeHook draw_paterson;
+extern ModeHook release_paterson;
+extern ModeSpecOpt paterson_opts;
+#endif
+
 #ifdef MODE_penrose
 extern ModeHook init_penrose;
 extern ModeHook draw_penrose;
@@ -1511,6 +1516,14 @@ extern ModeHook refresh_spiral;
 extern ModeSpecOpt spiral_opts;
 #endif
 
+#ifdef MODE_spirolateral
+extern ModeHook init_spirolateral;
+extern ModeHook draw_spirolateral;
+extern ModeHook release_spirolateral;
+extern ModeHook refresh_spirolateral;
+extern ModeSpecOpt spirolateral_opts;
+#endif
+
 #ifdef MODE_spline
 extern ModeHook init_spline;
 extern ModeHook draw_spline;
@@ -1526,6 +1539,13 @@ extern ModeHook release_sproingies;
 extern ModeSpecOpt sproingies_opts;
 #endif
 
+#ifdef MODE_squiral
+extern ModeHook init_squiral;
+extern ModeHook draw_squiral;
+extern ModeHook release_squiral;
+extern ModeSpecOpt squiral_opts;
+#endif
+
 #ifdef MODE_stairs
 extern ModeHook init_stairs;
 extern ModeHook draw_stairs;
